@@ -14,6 +14,7 @@ pub(super) struct Data {
     /// Top level scope uses [SyntaxContext::empty].
     pub scopes: AHashMap<SyntaxContext, ScopeData>,
     pub ops: RefCell<Operations>,
+    idx_cache: AHashMap<JsWord, usize>,
 }
 
 #[derive(Debug, Default)]
@@ -233,9 +234,9 @@ impl UsageAnalyzer<'_> {
     }
 
     fn new_symbol(&mut self, orig: Id) -> JsWord {
-        let mut i = 0;
+        let i = self.data.idx_cache.entry(orig.0.clone()).or_default();
         loop {
-            i += 1;
+            *i += 1;
             let word: JsWord = format!("{}{}", orig.0, i).into();
 
             if self.data.ops.get_mut().is_used_as_rename_target(&word) {
